@@ -5,7 +5,7 @@ import (
 
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/client"
-	"github.com/superfly/flyctl/internal/app"
+	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 )
@@ -31,7 +31,7 @@ func newList() *cobra.Command {
 func runIPAddressesList(ctx context.Context) error {
 	client := client.FromContext(ctx).API()
 
-	appName := app.NameFromContext(ctx)
+	appName := appconfig.NameFromContext(ctx)
 	ipAddresses, err := client.GetIPAddresses(ctx, appName)
 	if err != nil {
 		return err
